@@ -2,8 +2,6 @@ package Minions::_Guts;
 
 use Digest::MD5 qw( md5_hex );
 
-*attribute_sym = \ substr(md5_hex($$), 0 ,8);
-
 our %obfu_name;
 
 sub obfu_name {
@@ -17,4 +15,10 @@ sub obfu_name {
     }
 }
 
+sub attribute_sym {
+    my $datum = shift || $$;
+
+    return substr(md5_hex($datum), 0 ,8);
+}
+
 1;
