@@ -1,17 +1,15 @@
 package Example::Construction::Acme::Counter;
 
-use strict;
-
-our %__Meta = (
+use Minions::Implementation
     has  => {
         count => { init_arg => 'start' },
     }, 
-);
+;
 
 sub next {
     my ($self) = @_;
 
-    $self->{$$}{count}++;
+    $self->{$__count}++;
 }
 
 1;
